<?php

/**
 * Wizard start form for layout choosing.
 */
function layouter_choose_layout_form($form, &$form_state) {
  $form_state['title'] = t('Layouter');

  $templates = layouter_templates();
  $options = array();
  foreach ($templates as $id => $template) {
    $options[$id] = $template['title'];
  }

  $form['type'] = array(
    '#title' => t('Choose the layout'),
    '#type' => 'radios',
    '#options' => $options,
    '#default_value' => $form_state['object']->type,
    '#required' => 1,
    '#after_build' => array('_layouter_process_layout_type_radios')
  );
  $form['#attributes']['class'][] = 'layouter-form';
  $form['#attached']['css'] = array(
    drupal_get_path('module', 'layouter') . '/theme/layouter.css'
  );

  return $form;
}

function layouter_choose_layout_form_submit($form, &$form_state) {
  $form_state['object']->type = $form_state['values']['type'];
  // Override where to go next based on the template selected.
  $form_state['clicked_button']['#next'] = $form_state['values']['type'];
}

/**
 * Form for adding content for img_only layout.
 */
function layouter_img_only_form($form, &$form_state) {
  $form_state['title'] = $form_state['form_info']['forms'][$form_state['step']]['form title'];
  $allowed_extensions = array('png gif jpeg jpg');
  $max_upload_size_mb = (int) ini_get('upload_max_filesize');
  $max_upload_size = array($max_upload_size_mb * 1024 * 1024);
//  $max_resolution = array('640x480');
  $image_field_description = t('Files must be less than !size.', array('!size' => '<strong>' . format_size($max_upload_size[0]) . '</strong>'));
  $image_field_description .= '<br />' . t('Allowed file types: !extensions.', array('!extensions' => '<strong>' . $allowed_extensions[0] . '</strong>'));
  $image_styles = image_styles();
  $image_styles_options = array();
  foreach ($image_styles as $k => $v) {
    $image_styles_options[$k] = $k;
  }
  $admin_image_style_descr = '';
  if (user_access('administer image styles')) {
    $admin_image_style_descr = '<br />' . t('You can also <a href="@image_styles">add your own image style</a> if you need to.', array('@image_styles' => url('admin/config/media/image-styles')));
  }
  
  $form['image'] = array(
    '#type' => 'managed_file',
    '#title' => t('Image'),
    '#description' => $image_field_description,
    '#required' => 1,
    '#upload_location' => 'public://layouter_images',
    '#upload_validators' => array(
      'file_validate_extensions' => $allowed_extensions,
      'file_validate_size' => array($max_upload_size),
//      'file_validate_image_resolution' => $max_resolution
    )
  );
  $form['image_style'] = array(
    '#type' => 'select',
    '#title' => t('Image style'),
    '#options' => $image_styles_options,
    '#required' => 1,
    '#description' => t('Choose the image style preset that you want your image to be rendered with.') . $admin_image_style_descr
  );
  
  return $form;
}

function layouter_img_only_form_submit($form, &$form_state) {
  $values = $form_state['values'];
  $image_fid = $values['image'];
  $image_style = $values['image_style'];
  
  $image_file = file_load($image_fid);
  $image_file->status = FILE_STATUS_PERMANENT;
  file_save($image_file);
  
  $image = theme('image_style', array('style_name' => $image_style, 'path' => $image_file->uri));
  $textarea_id = $form_state['textarea_id'];
  // Apply the layout to the content.
  $content = theme('layouter_image_only', array('image' => $image));
  // Insert it into textarea field.
  layouter_insert_content_into_textarea($textarea_id, $content);
}

/**
 * Form for adding content for two_columns layout.
 */
function layouter_two_columns_form($form, &$form_state) {
  $form_state['title'] = $form_state['form_info']['forms'][$form_state['step']]['form title'];
  
  $form['text_content'] = array(
    '#type' => 'textarea',
    '#title' => t('Text'),
    '#rows' => 15,
    '#required' => 1
  );
  
  return $form;
}

function layouter_two_columns_form_submit($form, &$form_state) {
  $values = $form_state['values'];
  $text_content = strip_tags($values['text_content']);
  $textarea_id = $form_state['textarea_id'];
  // Apply the layout to the content.
  $content = theme('layouter_two_columns', array('text' => $text_content));
  // Insert it into textarea field.
  layouter_insert_content_into_textarea($textarea_id, $content);
}

/**
 * Form for adding content for two_columns_img_left_text_right layout.
 */
function layouter_img_caption_text_form($form, &$form_state) {
  $form_state['title'] = $form_state['form_info']['forms'][$form_state['step']]['form title'];
  $allowed_extensions = array('png gif jpeg jpg');
  $max_upload_size_mb = (int) ini_get('upload_max_filesize');
  $max_upload_size = array($max_upload_size_mb * 1024 * 1024);
//  $max_resolution = array('640x480');
  $image_field_description = t('Files must be less than !size.', array('!size' => '<strong>' . format_size($max_upload_size[0]) . '</strong>'));
  $image_field_description .= '<br />' . t('Allowed file types: !extensions.', array('!extensions' => '<strong>' . $allowed_extensions[0] . '</strong>'));
  $image_styles = image_styles();
  $image_styles_options = array();
  foreach ($image_styles as $k => $v) {
    $image_styles_options[$k] = $k;
  }
  
  $form['text_content'] = array(
    '#type' => 'textarea',
    '#title' => t('Text'),
    '#rows' => 15,
    '#required' => 1
  );
  $form['image_content'] = array(
    '#type' => 'fieldset',
    '#tree' => 1,
    '#title' => t('Image'),
  );
  $form['image_content']['image'] = array(
    '#type' => 'managed_file',
    '#title' => t('Image'),
    '#description' => $image_field_description,
    '#required' => 1,
    '#upload_location' => 'public://layouter_images',
    '#upload_validators' => array(
      'file_validate_extensions' => $allowed_extensions,
      'file_validate_size' => array($max_upload_size),
//      'file_validate_image_resolution' => $max_resolution
    )
  );
  $form['image_content']['image_style'] = array(
    '#type' => 'select',
    '#title' => t('Image style'),
    '#options' => $image_styles_options,
    '#required' => 1
  );
  $form['image_content']['caption'] = array(
    '#type' => 'textarea',
    '#title' => t('Caption')
  );
  
  return $form;
}

function layouter_img_caption_text_form_submit($form, &$form_state) {
  $values = $form_state['values'];
  $text_content = strip_tags($values['text_content']);
  $image_fid = $values['image_content']['image'];
  $image_style = $values['image_content']['image_style'];
  $caption = strip_tags($values['image_content']['caption']);
  
  $image_file = file_load($image_fid);
  $image_file->status = FILE_STATUS_PERMANENT;
  file_save($image_file);
  
  $image = theme('image_style', array('style_name' => $image_style, 'path' => $image_file->uri));
  $textarea_id = $form_state['textarea_id'];
  // As we use the same form for different layouts we need to know which template to apply.
  $theme = $form_state['form_info']['forms'][$form_state['step']]['theme'];
  // Apply the layout to the content.
  $content = theme($theme, array('text' => $text_content, 'image' => $image, 'caption' => $caption));
  // Insert it into textarea field.
  layouter_insert_content_into_textarea($textarea_id, $content);
}

/**
 * Form for adding content for two_columns_text_img_left layout.
 */
function layouter_text_img_form($form, &$form_state) {
  $form_state['title'] = $form_state['form_info']['forms'][$form_state['step']]['form title'];
  $allowed_extensions = array('png gif jpeg jpg');
  $max_upload_size_mb = (int) ini_get('upload_max_filesize');
  $max_upload_size = array($max_upload_size_mb * 1024 * 1024);
//  $max_resolution = array('640x480');
  $image_field_description = t('Files must be less than !size.', array('!size' => '<strong>' . format_size($max_upload_size[0]) . '</strong>'));
  $image_field_description .= '<br />' . t('Allowed file types: !extensions.', array('!extensions' => '<strong>' . $allowed_extensions[0] . '</strong>'));
  $image_styles = image_styles();
  $image_styles_options = array();
  foreach ($image_styles as $k => $v) {
    $image_styles_options[$k] = $k;
  }
  
  $form['text_content'] = array(
    '#type' => 'textarea',
    '#title' => t('Text'),
    '#rows' => 15,
    '#required' => 1
  );
  $form['image_content'] = array(
    '#type' => 'fieldset',
    '#tree' => 1,
    '#title' => t('Image'),
  );
  $form['image_content']['image'] = array(
    '#type' => 'managed_file',
    '#title' => t('Image'),
    '#description' => $image_field_description,
    '#required' => 1,
    '#upload_location' => 'public://layouter_images',
    '#upload_validators' => array(
      'file_validate_extensions' => $allowed_extensions,
      'file_validate_size' => array($max_upload_size),
//      'file_validate_image_resolution' => $max_resolution
    )
  );
  $form['image_content']['image_style'] = array(
    '#type' => 'select',
    '#title' => t('Image style'),
    '#options' => $image_styles_options,
    '#required' => 1
  );
  
  return $form;
}

function layouter_text_img_form_submit($form, &$form_state) {
  $values = $form_state['values'];
  $text_content = strip_tags($values['text_content']);
  $image_fid = $values['image_content']['image'];
  $image_style = $values['image_content']['image_style'];
  
  $image_file = file_load($image_fid);
  $image_file->status = FILE_STATUS_PERMANENT;
  file_save($image_file);
  
  $image = theme('image_style', array('style_name' => $image_style, 'path' => $image_file->uri));
  $textarea_id = $form_state['textarea_id'];
  // As we use the same form for different layouts we need to know which template to apply.
  $theme = $form_state['form_info']['forms'][$form_state['step']]['theme'];
  // Apply the layout to the content.
  $content = theme($theme, array('text' => $text_content, 'image' => $image));
  // Insert it into textarea field.
  layouter_insert_content_into_textarea($textarea_id, $content);
}
